Documentation
¶
Index ¶
Constants ¶
const ( ParamLayersPerEpoch = "layers-per-epoch" ParamLayerDuration = "layer-duration" )
Variables ¶
var ( LayerDuration = parameters.Duration( ParamLayerDuration, "layer duration in seconds", 5*time.Second, ) LayersPerEpoch = parameters.Int( ParamLayersPerEpoch, "number of layers in an epoch", 4, ) )
Functions ¶
This section is empty.
Types ¶
type Context ¶
type Context struct {
context.Context
Client *kubernetes.Clientset
Parameters *parameters.Parameters
BootstrapDuration time.Duration
ClusterSize int
BootnodeSize int
RemoteSize int
PoetSize int
OldSize int
BootstrapperSize int
Generic client.Client
TestID string
Keep bool
Namespace string
Image string
OldImage string
BootstrapperImage string
CertifierImage string
PoetImage string
PostServiceImage string
PostInitImage string
Storage struct {
Size string
Class string
}
NodeSelector map[string]string
Log *zap.SugaredLogger
}
Context must be created for every test that needs isolated cluster.
type Opt ¶
type Opt func(*cfg)
Opt is for configuring Context.
func SkipClusterLimits ¶
func SkipClusterLimits() Opt
SkipClusterLimits will not block if there are no available tokens.
Click to show internal directories.
Click to hide internal directories.